@@ -113,7 +113,8 @@ sub output {
 
     my $script_name = $config->script_name;
     my $script_url  = $config->script_url;
-
+    my $default_city = $config->default_city;
+    
     # Check cookie to see if we need to set the formatting_rules_link.
     my ($formatting_rules_link, $omit_help_links);
     my $formatting_rules_node = $config->formatting_rules_node;
@@ -150,6 +151,7 @@ sub output {
                     openguides_version    => $OpenGuides::VERSION,
                     enable_page_deletion  => $enable_page_deletion,
                     language              => $config->default_language,
+                    default_city          => $default_city,
     };
 
     if ($args{node}) {
@@ -490,7 +492,7 @@ The OpenGuides Project (openguides-dev@openguides.org)
 
 =head1 COPYRIGHT
 
-  Copyright (C) 2003-2004 The OpenGuides Project.  All Rights Reserved.
+  Copyright (C) 2003-2005 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
